@@ -1,10 +1,10 @@
-use display_info::{get_display_info_from_point, get_display_infos};
+use display_info::DisplayInfo;
 use std::time::Instant;
 
 fn main() {
   let start = Instant::now();
 
-  let display_infos = get_display_infos();
+  let display_infos = DisplayInfo::all();
   for display_info in display_infos {
     println!(
       "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
@@ -17,7 +17,7 @@ fn main() {
       display_info.rotation
     );
   }
-  let display_info = get_display_info_from_point(100, 100).unwrap();
+  let display_info = DisplayInfo::from_point(100, 100).unwrap();
   println!("display_info {:?}", display_info);
   println!(
     "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
