@@ -1,4 +1,4 @@
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub struct DisplayInfo {
   pub id: u32,
   pub x: i32,
